#
# spec file for package secrets
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global         flavor %nil
%if "%{flavor}" == "test"
%define         psuffix -test
%else
%define         psuffix %nil
%endif
Name:           secrets%{psuffix}
Version:        11.1.1
Release:        1.1
Summary:        A password manager for GNOME
License:        GPL-3.0-only
URL:            https://gitlab.gnome.org/World/secrets
Source0:        secrets-%{version}.tar.zst
Patch0:         fix-test.patch
BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  meson >= 0.64.0
BuildRequires:  pkgconfig
BuildRequires:  python3-PyKCS11
BuildRequires:  python3-base >= 3.8.0
BuildRequires:  python3-gobject
BuildRequires:  python3-gobject-Gdk
BuildRequires:  python3-pykeepass >= 4.1.1
BuildRequires:  python3-pyotp >= 2.4.0
BuildRequires:  python3-pytest
BuildRequires:  python3-python-yubico
BuildRequires:  python3-validators
BuildRequires:  python3-zxcvbn-rs-py
BuildRequires:  pkgconfig(gio-2.0) >= 2.66
BuildRequires:  pkgconfig(glib-2.0) >= 2.73.1
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.66.0
BuildRequires:  pkgconfig(gtk4) >= 4.15.3
BuildRequires:  pkgconfig(gtksourceview-5) >= 5.0
BuildRequires:  pkgconfig(libadwaita-1) >= 1.7
BuildRequires:  pkgconfig(pygobject-3.0) >= 3.52.0

Requires:       opensc
Requires:       python3-PyKCS11
Requires:       python3-argon2-cffi
Requires:       python3-gobject-Gdk
Requires:       python3-lxml
Requires:       python3-pycryptodome
Requires:       python3-pykeepass
Requires:       python3-pyotp
Requires:       python3-python-yubico
Requires:       python3-pyusb
Requires:       python3-validators
Requires:       python3-zxcvbn-rs-py

Obsoletes:      gnome-passwordsafe < 6.1
Provides:       gnome-passwordsafe = %{version}

%if "%{flavor}" == "test"
BuildRequires:  secrets = %{version}
%endif

BuildArch:      noarch

%description
Secrets is a password manager which makes use of the Keepass v.4
format.
It integrates with the GNOME desktop and provides an interface for
the management of password databases.

%lang_package

%prep
%autosetup -p1 -n secrets-%{version}
# Fix shebang to be py3, not env set
sed -i -e '1{s,^#!/usr/bin/env python3,#!%{_bindir}/python3,}' gsecrets/utils.py
# Drop shebang all the way
sed -i -e '1{s,^#!@PYTHON@,,}' gsecrets/const.py.in

%build
%meson
%meson_build

%if "%{flavor}" != "test"
%install
%meson_install
# Explicitly create the pycache/.pyc files, not relying on the
# generation done by meson. Should make the package reproducible.
%py3_compile %{buildroot}%{python3_sitelib}/gsecrets
%find_lang secrets %{?no_lang_C}
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.xml
glib-compile-schemas --strict --dry-run %{buildroot}%{_datadir}/glib-2.0/schemas/
%endif

%if "%{flavor}" == "test"
%check
pytest
%endif

%if "%{flavor}" != "test"
%files
%license LICENSE
%doc README.md
%{_bindir}/secrets
%{python3_sitelib}/gsecrets/
%{_datadir}/applications/org.gnome.World.Secrets.desktop
%dir %{_datadir}/secrets
%{_datadir}/%{name}/resources.gresource
%{_datadir}/glib-2.0/schemas/org.gnome.World.Secrets.gschema.xml
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.World.Secrets-symbolic.svg
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.World.Secrets.svg
%{_datadir}/metainfo/org.gnome.World.Secrets.metainfo.xml
%{_datadir}/mime/packages/org.gnome.World.Secrets.xml

%files lang -f secrets.lang
%endif

%changelog
* Mon Apr 21 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 11.1.1:
  + Declare on meson that we depend on pygobject 3.52.
  + Updated translations.
* Thu Apr 10 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 11.0:
  * use newer widgets from libadwaita 1.7
  * update to GNOME 48
  * Show real database path
  * Add quick unlock setting
  * Add fingerprint reader support
  * Improve sidebar's width
  * Various bug fixes
  * Updated translations
- add new dependencies, according to meson.build
- update fix-test.patch, as the second test has now the same issue
  as the first one
* Sun Jan  5 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 10.4:
  + Fix crash when closing a dialog when the db is locked.
  + Fix crash when using zxcvbn-rs 0.2.
  + Various bug fixes.
* Mon Nov 11 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 10.3:
  * Do not allow multiple preferences dialogs simultaneously
  * Fix crash when deleting trash bin
* Thu Oct 17 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 10.2:
  * Correctly select element after creating it
  * Prevents data corruption when saving on certain virtual file
    systems
  * Prevents a crash when deleting elements in trash
- Drop update-desktop-files and corresponding macro, they are not
  needed on current versions of openSUSE.
* Sun Oct 13 2024 Richard Rahl <rrahl0@opensuse.org>
- change runtime dependency to python3-zxcvbn-rs-py, as since version
  10, upstream switched from python3-zxcvbn to the rust version of
  zxcvbn (where we need to python bindings)
* Mon Sep 23 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 10.1:
  * Fixes crash while searching
- update to 10:
  * Use newer widgets from libadwaita 1.6 and update to the GNOME 47
  * Add tag support
  * Migrate from zxcvbn to zxcvbn-rs
  * Various bug fixes
  * Updated translations
* Fri Jul 19 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 9.6:
  * Improve password generation threading
  * Fix crash on changing DB password
* Sat Jun 22 2024 Richard Rahl <rrahl0@disroot.org>
- update to 9.5:
  * Fix entering group in selection mode
  * Do not freeze on loading DB
  * Fix crash on duplicating an entry twice
  * Improve focus in dialogs
* Fri May 17 2024 Richard Rahl <rrahl0@disroot.org>
- update to 9.4:
  * Align entry copy buttons
  * Set url button to insensitive if there is no url
  * Update pykeepass to 4.0.7.post1
  * Refresh token list async
  * Fix crash when deleting entries
  * Fix glitch on expiration setting
  * Exit selection mode after actions
  * Switch group row enter and edit functionality
  * Use progress bar for unlocking database
- add fix-test.patch to fix the running the test
* Mon Apr  1 2024 Richard Rahl <rrahl0@proton.me>
- Update to version 9.3:
  + Catch YubiKey errors
  + Fix row titles markup
  + Add back safe authentication settings
- Update to version 9.2:
  + Fix safe creation
  + Fix safe properties
  + Fix sidebar size
- Update to version 9.1:
  + Temporarily disable credentials change dialog
  + Use ruff to format and lint the project
  + Fix style when selecting an entry
  + Fix crash when decoding timestamps
  + Fix crash when opening certain file dialogs
  + Fix crash when deleting element from trash bin
- Update to version 9.0:
  + Add PKCS11 support
  + Add YubiKey support
  + Use new dual panel layout
  + Set monospace only for revealed passwords
  + Introduce key providers
- enable selftest
* Tue Sep 26 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 8.0:
  + Use newer widgets from libadwaita 1.4 and update to the GNOME
    45 Sdk.
  + Improved search performance
  + Improved accessibility
  + Multiple bug fixes
  + Update to pykeepass 4.0.6
  + Hide values of sensitive attributes.
- Change compression of tarball in service and spec to zst from xz.
- Explicitly create the pycache/.pyc files, not relying on the
  generation done by meson. Should make the package reproducible.
- Stop passing tests=true to meson setup, no longer needed, nor
  recognized.
* Wed May  3 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 7.3:
  + Use newer widgets from gtk 4.10 and update to the GNOME 44 Sdk.
* Tue Feb 21 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 7.2:
  + Fixes a crash when deleting elements
- Changes from version 7.1:
  + Minor bugfixes
* Mon Oct 17 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 7.0:
  + Added support for the trash bin, deletions now go to the trash
    and can be undone.
  + Check for file conflicts before saving.
  + Add support for password history.
  + Add a Ctrl+V action and a button to copy an entry's URL.
  + Add support for trash bin.
  + Use newer widgets from libadwaita.
  + Update pykeepass to 4.0.3.
  + Redesigned attributes.
  + Bug fixes.
- Drop 0001-Update-pykeepass-to-4.0.3.patch: Fixed upstream.
- Add python3-validators and python3-zxcvbn: New BuildRequires.
- Drop python3-construct, pkgconfig(pwquality), python3-construct
  and python3-pwquality BuildRequires/Requires, no longer needed.
- Disable meson_test macro for now, currently fails without
  BuildRequires secrets. This is something we need to take up with
  upstream. Validate desktop files, schemas and appdata manually.
* Wed Aug 17 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream change to fix build with recent pykeepass versions:
  * 0001-Update-pykeepass-to-4.0.3.patch
* Wed Jun 29 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 6.5:
  + Fix a crash that happens when the native file chooser returns
    NULL as a file.
- Changes from version 6.4:
  + Fix a crash when creating a new database under certain
    circumstances.
- Changes from version 6.3:
  + Minor bugfix release.
  + Save operations are now atomic.
  + Updated translations.
* Mon Feb 28 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 6.2:
  + Minor bugfix release.
  + Updated translations.
* Thu Feb 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Initial packaging for openSUSE.
